@@ -1,11 +1,11 @@
 import datetime
 import os
 import sys
-from copy import deepcopy
 from datetime import timedelta
 from enum import Enum
-from typing import Union, List, Optional
+from typing import Union, List
 
+from django.conf import settings
 from django.contrib import auth
 from django.contrib.auth.models import BaseUserManager, Group, Permission
 from django.contrib.contenttypes.fields import GenericForeignKey
@@ -14,7 +14,6 @@ from django.db import models
 from django.db.models import Q
 from django.db.models.signals import pre_delete
 from django.dispatch import receiver
-from django.urls import reverse
 from django.utils import timezone
 from mptt.fields import TreeForeignKey
 from mptt.models import MPTTModel
@@ -275,6 +274,13 @@ class User(models.Model):
 		except StaffCharge.DoesNotExist:
 			return None
 
+	def get_preferences(self):
+		if not self.preferences:
+			default_reservation_preferences = getattr(settings, 'USER_RESERVATION_PREFERENCES_DEFAULT', False)
+			self.preferences = UserPreferences.objects.create(attach_cancelled_reservation=default_reservation_preferences, attach_created_reservation=default_reservation_preferences)
+			self.save()
+		return self.preferences
+
 	@classmethod
 	def get_email_field_name(cls):
 		return 'email'
@@ -1526,6 +1532,7 @@ class Door(models.Model):
 		return str(self.name)
 
 	def get_absolute_url(self):
+		from django.urls import reverse
 		return reverse('welcome_screen', args=[self.id])
 	get_absolute_url.short_description = 'URL'
 
