@@ -102,7 +102,7 @@ def calendar(request, item_type=None, item_id=None):
 @require_GET
 @disable_session_expiry_refresh
 def event_feed(request):
-	""" Get all reservations for a specific time-window. Optionally: filter by tool or user name. """
+	""" Get all reservations for a specific time-window. Optionally: filter by tool, area or user name. """
 	try:
 		start, end = extract_dates(request.GET)
 	except Exception as e:
@@ -183,25 +183,26 @@ def usage_event_feed(request, start, end):
 	if item_id and item_type == ReservationItemType.TOOL:
 		usage_events = usage_events.filter(tool__id__in=Tool.objects.get(pk=item_id).get_family_tool_ids())
 
-	area_access_events = None
+	area_access_events = AreaAccessRecord.objects.none()
 	# Filter events that only have to do with the current user.
 	personal_schedule = request.GET.get('personal_schedule')
 	if personal_schedule:
 		usage_events = usage_events.filter(user=request.user)
 		# Display area access along side tool usage when 'personal schedule' is selected.
 		area_access_events = AreaAccessRecord.objects.filter(customer__id=request.user.id)
-		area_access_events = area_access_events.exclude(start__lt=start, end__lt=start)
-		area_access_events = area_access_events.exclude(start__gt=end, end__gt=end)
+	if item_id and item_type == ReservationItemType.AREA:
+		area_access_events = AreaAccessRecord.objects.filter(area__id=item_id)
+	area_access_events = area_access_events.exclude(start__lt=start, end__lt=start)
+	area_access_events = area_access_events.exclude(start__gt=end, end__gt=end)
 
-	missed_reservations = None
+	missed_reservations = Reservation.objects.none()
 	if personal_schedule:
 		missed_reservations = Reservation.objects.filter(missed=True, user=request.user)
 	elif item_type:
 		reservation_filter = {item_type.value: item_id}
 		missed_reservations = Reservation.objects.filter(missed=True).filter(**reservation_filter)
-	if missed_reservations:
-		missed_reservations = missed_reservations.exclude(start__lt=start, end__lt=start)
-		missed_reservations = missed_reservations.exclude(start__gt=end, end__gt=end)
+	missed_reservations = missed_reservations.exclude(start__lt=start, end__lt=start)
+	missed_reservations = missed_reservations.exclude(start__gt=end, end__gt=end)
 
 	dictionary = {
 		'usage_events': usage_events,
@@ -917,11 +918,14 @@ def cancel_the_reservation(reservation: Reservation, user_cancelling_reservation
 			email_contents = get_media_file_contents('cancellation_email.html')
 			if email_contents:
 				cancellation_email = Template(email_contents).render(Context(dictionary))
-				if getattr(reservation.user.preferences, 'attach_cancelled_reservation', False):
+				recipients = [reservation.user.email]
+				if reservation.area:
+					recipients.extend(reservation.area.reservation_email_list())
+				if reservation.user.get_preferences().attach_cancelled_reservation:
 					attachment = create_ics_for_reservation(reservation, cancelled=True)
-					reservation.user.email_user('Your reservation was cancelled', cancellation_email, user_cancelling_reservation.email, [attachment])
+					send_mail('Your reservation was cancelled', cancellation_email, user_cancelling_reservation.email, recipients, [attachment])
 				else:
-					reservation.user.email_user('Your reservation was cancelled', cancellation_email, user_cancelling_reservation.email)
+					send_mail('Your reservation was cancelled', cancellation_email, user_cancelling_reservation.email, recipients)
 
 		else:
 			''' here the user cancelled his own reservation so notify him '''
@@ -957,7 +961,7 @@ def send_out_of_time_reservation_notification(reservation:Reservation):
 
 def send_user_created_reservation_notification(reservation: Reservation):
 	site_title = get_customization('site_title')
-	recipients = [reservation.user.email] if getattr(reservation.user.preferences, 'attach_created_reservation', False) else []
+	recipients = [reservation.user.email] if reservation.user.get_preferences().attach_created_reservation else []
 	if reservation.area:
 		recipients.extend(reservation.area.reservation_email_list())
 	if recipients:
@@ -975,7 +979,7 @@ def send_user_created_reservation_notification(reservation: Reservation):
 
 def send_user_cancelled_reservation_notification(reservation: Reservation):
 	site_title = get_customization('site_title')
-	recipients = [reservation.user.email] if getattr(reservation.user.preferences, 'attach_cancelled_reservation', False) else []
+	recipients = [reservation.user.email] if reservation.user.get_preferences().attach_cancelled_reservation else []
 	if reservation.area:
 		recipients.extend(reservation.area.reservation_email_list())
 	if recipients:
