@@ -5,15 +5,16 @@ from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.auth.decorators import login_required
 from django.core.mail import EmailMultiAlternatives
 from django.core.validators import validate_email
-from django.http import HttpResponseBadRequest
+from django.db.models import Q
+from django.http import HttpResponseBadRequest, HttpResponse
 from django.shortcuts import render, get_object_or_404
 from django.template import Template, Context
+from django.utils.safestring import mark_safe
 from django.views.decorators.http import require_GET, require_POST
 
 from NEMO.forms import EmailBroadcastForm
-from NEMO.models import Tool, Account, Project, User
-from NEMO.views.customization import get_media_file_contents
-
+from NEMO.models import Tool, Account, Project, User, Area, PhysicalAccessLevel
+from NEMO.views.customization import get_media_file_contents, get_customization
 
 logger = getLogger(__name__)
 
@@ -55,7 +56,8 @@ def send_email(request):
 		email.attach_alternative(body, 'text/html')
 		email.send()
 	except SMTPException as error:
-		error_message = 'NEMO was unable to send the email through the email server. The error message that NEMO received is: ' + str(error)
+		site_title = get_customization('site_title')
+		error_message = f'{site_title} was unable to send the email through the email server. The error message that was received is: ' + str(error)
 		logger.exception(error_message)
 		dictionary = {
 			'title': 'Email not sent',
@@ -76,6 +78,8 @@ def email_broadcast(request, audience=''):
 	dictionary = {}
 	if audience == 'tool':
 		dictionary['search_base'] = Tool.objects.filter(visible=True)
+	elif audience == 'area':
+		dictionary['search_base'] = Area.objects.filter(requires_reservation=True)
 	elif audience == 'project':
 		dictionary['search_base'] = Project.objects.filter(active=True, account__active=True)
 	elif audience == 'account':
@@ -92,6 +96,13 @@ def compose_email(request):
 	try:
 		if audience == 'tool':
 			users = User.objects.filter(qualifications__id=selection).distinct()
+		elif audience == 'area':
+			access_levels = Area.objects.get(pk=selection).get_physical_access_levels()
+			user_filter = Q(physical_access_levels__in=access_levels)
+			# if one of the access levels allows staff, add all staff
+			if access_levels.filter(allow_staff_access=True).exists():
+				user_filter = user_filter | Q(is_staff=True)
+			users = User.objects.filter(user_filter).distinct()
 		elif audience == 'project':
 			users = User.objects.filter(projects__id=selection).distinct()
 		elif audience == 'account':
@@ -113,6 +124,7 @@ def compose_email(request):
 			'title': 'TITLE',
 			'greeting': 'Greeting',
 			'contents': 'Contents',
+			'template_color': '#5bc0de',
 		}
 		dictionary['generic_email_sample'] = Template(generic_email_sample).render(Context(generic_email_context))
 	return render(request, 'email/compose_email.html', dictionary)
@@ -121,8 +133,9 @@ def compose_email(request):
 @staff_member_required(login_url=None)
 @require_POST
 def send_broadcast_email(request):
-	if not get_media_file_contents('generic_email.html'):
-		return HttpResponseBadRequest('Generic email template not defined. Visit the NEMO customizable_key_values page to upload a template.')
+	content = get_media_file_contents('generic_email.html')
+	if not content:
+		return HttpResponseBadRequest('Generic email template not defined. Visit the customization page to upload a template.')
 	form = EmailBroadcastForm(request.POST)
 	if not form.is_valid():
 		return render(request, 'email/compose_email.html', {'form': form})
@@ -132,7 +145,6 @@ def send_broadcast_email(request):
 		'contents': form.cleaned_data['contents'],
 		'template_color': form.cleaned_data['color'],
 	}
-	content = get_media_file_contents('generic_email.html')
 	content = Template(content).render(Context(dictionary))
 	users = None
 	audience = form.cleaned_data['audience']
@@ -150,7 +162,7 @@ def send_broadcast_email(request):
 	except Exception as error:
 		warning_message = 'Your email was not sent. There was a problem finding the users to send the email to.'
 		dictionary = {'error': warning_message}
-		logger.warning(warning_message + ' audience: {}, only_active: {}. The error message that NEMO received is: {}'.format(audience, active_choice, str(error)))
+		logger.warning(warning_message + ' audience: {}, only_active: {}. The error message that was received is: {}'.format(audience, active_choice, str(error)))
 		return render(request, 'email/compose_email.html', dictionary)
 	if not users:
 		dictionary = {'error': 'The audience you specified is empty. You must send the email to at least one person.'}
@@ -164,7 +176,8 @@ def send_broadcast_email(request):
 		email.attach_alternative(content, 'text/html')
 		email.send()
 	except SMTPException as error:
-		error_message = 'NEMO was unable to send the email through the email server. The error message that NEMO received is: ' + str(error)
+		site_title = get_customization('site_title')
+		error_message = f"{site_title} was unable to send the email through the email server. The error message that was received is: " + str(error)
 		logger.exception(error_message)
 		dictionary = {
 			'title': 'Email not sent',
@@ -177,3 +190,20 @@ def send_broadcast_email(request):
 		'heading': 'Your email was sent',
 	}
 	return render(request, 'acknowledgement.html', dictionary)
+
+
+@staff_member_required(login_url=None)
+@require_POST
+def email_preview(request):
+	generic_email_template = get_media_file_contents('generic_email.html')
+	if generic_email_template:
+		form = EmailBroadcastForm(request.POST)
+		email_context = {
+			'title': form.data['title'],
+			'greeting': form.data['greeting'],
+			'contents': form.data['contents'],
+			'template_color': form.data['color'],
+		}
+		email_content = Template(generic_email_template).render(Context(email_context))
+		return HttpResponse(mark_safe(email_content))
+	return HttpResponse()
